@@ -3,7 +3,6 @@ mod sysinfo_ffi;
 use crate::extra;
 use crate::extra::list_dir_entries;
 use crate::traits::*;
-use aparato::{Fetch, PCIDevice};
 use byte_unit::AdjustedByte;
 use itertools::Itertools;
 use std::fs;
@@ -175,16 +174,63 @@ impl GeneralReadout for LinuxGeneralReadout {
         }
     }
 
+    fn backlight(&self) -> Result<usize, ReadoutError> {
+        use std::path::Path;
+        let root_backlight_path = extra::list_dir_entries(Path::new("/sys/class/backlight/"))
+            .into_iter()
+            .next();
+
+        if let Some(backlight_path) = root_backlight_path {
+            let max_brightness_path = backlight_path.join("max_brightness");
+
+            let current_brightness_path = backlight_path.join("brightness");
+
+            let max_brightness_value = extra::pop_newline(fs::read_to_string(max_brightness_path)?)
+                .parse::<usize>()
+                .ok();
+
+            let current_brightness_value =
+                extra::pop_newline(fs::read_to_string(current_brightness_path)?)
+                    .parse::<usize>()
+                    .ok();
+
+            match (current_brightness_value, max_brightness_value) {
+                (Some(c), Some(m)) => {
+                    let brightness = c as f32 / m as f32 * 100f32;
+                    if let Ok(br) = format!("{}", brightness).parse::<usize>() {
+                        return Ok(br);
+                    } else {
+                        return Err(ReadoutError::Other(String::from(
+                            "Failed to parse backlight value.",
+                        )));
+                    }
+                }
+                _ => {
+                    return Err(ReadoutError::Other(String::from(
+                        "Error occurred while calculating backlight (brightness) value.",
+                    )));
+                }
+            }
+        }
+
+        Err(ReadoutError::Other(String::from(
+            "Could not obtain backlight (brightness) information.",
+        )))
+    }
+
     fn resolution(&self) -> Result<String, ReadoutError> {
         let drm = Path::new("/sys/class/drm");
         if drm.is_dir() {
             let mut resolutions: Vec<String> = Vec::new();
 
+            // Iterate through symbolic links in /sys/class/drm
             for entry in extra::list_dir_entries(drm) {
                 if entry.read_link().is_ok() {
+                    // Append modes to /sys/class/drm/<device>/
                     let modes = std::path::PathBuf::from(entry).join("modes");
                     if modes.is_file() {
                         if let Ok(file) = std::fs::File::open(modes) {
+                            // Push the first line (if not empty) to the resolution vector
                             if let Some(line) = BufReader::new(file).lines().nth(0) {
                                 if let Ok(str) = line {
                                     resolutions.push(str);
@@ -241,7 +287,9 @@ impl GeneralReadout for LinuxGeneralReadout {
     }
 
     fn terminal(&self) -> Result<String, ReadoutError> {
-        // This function returns the PPID of a given PID.
+        // This function returns the PPID of a given PID:
+        //  - The file used to extract this data: /proc/<pid>/status
+        //  - This function parses and returns the value of the ppid line.
         fn get_parent(pid: i32) -> i32 {
             let process_path = PathBuf::from("/proc").join(pid.to_string()).join("status");
             let file = fs::File::open(process_path);
@@ -255,30 +303,37 @@ impl GeneralReadout for LinuxGeneralReadout {
                             return s_mem_kb.parse::<i32>().unwrap_or(-1);
                         }
                     }
+
                     -1
                 }
-                Err(_e) => -1,
+
+                Err(_) => -1,
             }
         }
 
-        // This function returns the name associated with the PPID. It can traverse
-        // `/proc` to find out the actual terminal in case of a nested shell situation
+        // This function returns the name associated with a given PPID
         fn terminal_name() -> String {
             let mut terminal_pid = get_parent(unsafe { libc::getppid() });
 
-            let shells = [
-                "sh", "su", "bash", "fish", "dash", "tcsh", "zsh", "ksh", "csh",
-            ];
             let path = PathBuf::from("/proc")
                 .join(terminal_pid.to_string())
                 .join("comm");
 
+            // Any command_name we find that matches
+            // one of the elements within this table
+            // is effectively ignored
+            let shells = [
+                "sh", "su", "nu", "bash", "fish", "dash", "tcsh", "zsh", "ksh", "csh",
+            ];
+
+            // The below loop will traverse /proc to find the
+            // terminal inside of which the user is operating
             if let Ok(mut terminal_name) = fs::read_to_string(path) {
                 while shells.contains(&terminal_name.replace("\n", "").as_str()) {
-                    let id = get_parent(terminal_pid);
-                    terminal_pid = id;
+                    let ppid = get_parent(terminal_pid);
+                    terminal_pid = ppid;
 
-                    let path = PathBuf::from("/proc").join(id.to_string()).join("comm");
+                    let path = PathBuf::from("/proc").join(ppid.to_string()).join("comm");
 
                     if let Ok(comm) = fs::read_to_string(path) {
                         terminal_name = comm;
@@ -299,7 +354,7 @@ impl GeneralReadout for LinuxGeneralReadout {
             ));
         }
 
-        Ok(extra::pop_newline(terminal))
+        Ok(terminal)
     }
 
     fn shell(&self, format: ShellFormat, kind: ShellKind) -> Result<String, ReadoutError> {
@@ -310,10 +365,6 @@ impl GeneralReadout for LinuxGeneralReadout {
         Ok(crate::shared::cpu_model_name())
     }
 
-    fn gpus(&self) -> Result<Vec<String>, ReadoutError> {
-        Ok(PCIDevice::fetch_gpus(None))
-    }
-
     fn cpu_usage(&self) -> Result<usize, ReadoutError> {
         let mut info = self.sysinfo;
         let info_ptr: *mut sysinfo = &mut info;
